@@ -1360,9 +1360,6 @@ class LaharFlowData(object):
 
         assert(var is not None), 'In POI_value, must give variable to extract as named argument var'
 
-        if not isinstance(var, list):
-            var = [var]
-
         if filename is not None:
             data = self._get_data(filename)
 
@@ -1370,6 +1367,8 @@ class LaharFlowData(object):
 
         indx = np.sqrt((data['x_distance']-POI_xy[0])**2+(data['y_distance']-POI_xy[1])**2)<buffer
         
+        n = len(indx)
+
         dt = [
             ('x_distance', np.float64),
             ('y_distance', np.float64),
@@ -1377,7 +1376,7 @@ class LaharFlowData(object):
             ('longitude', np.float64),
             (var, np.float64)]
 
-        data_clipped = np.full((indx.shape), np.nan, dtype=dt)
+        data_clipped = np.full((n), np.nan, dtype=dt)
 
         data_clipped[var] = data[var][indx]
         data_clipped['x_distance'] = data['x_distance'][indx]
